@@ -113,13 +113,13 @@ def nested_cross_validation(model,
     """
     results = defaultdict(list)
     target_col = "label"
-    splitter = KFold(inner_n_splits, task="classification")
+    splitter = KFold(outer_n_splits, task="classification")
     if (X is None) and (y is None):
         df = splitter.split_df(df, target_col, shuffle=True)
     else:
         df = splitter.split_X_y(X, y, shuffle=True)
 
-    for fold in range(inner_n_splits):
+    for fold in range(outer_n_splits):
         df_train = df[df["kfold"]!=fold]
         df_valid = df[df["kfold"]==fold]
         X_train = df_train.loc[:, df_train.columns!=target_col]
